require_relative '../spec_helper'
require_relative '../fixtures/base_fixture'

describe TurbaChronos::Timeline do
  before(:all) do
    Timecop.freeze(Time.zone.parse("July 30 2014, 16:15").iso8601)
    @subject = TurbaChronos.load(base.periods, Time.now.utc.iso8601, (Time.now.utc + 3.days).iso8601)
  end

  after(:all) do
    Timecop.return
  end

  describe '.business_timeranges' do
    it "returns the business hours timeranges for days" do
      expect(@subject.business_timeranges).to eql([["08:00", "10:00"], ["10:00", "17:00"]])
    end
  end

  describe '.timeranges_for_days' do
    it "returns the timeranges for days" do
      expect(@subject.timeranges_for_days[:timeranges].to_s).to eql("[0..800, 800..1000, 1000..1700, 1700..2359]")
    end
  end

  describe '.current_day' do
    it "returns the current day" do
      day = @subject.current_day
      expect(day.beginning_of_day.to_s).to eql("2014-07-30")
    end
  end

  describe '.current_timeframe' do
    it "returns the current timeframe" do
      # expect(@subject.current_timeframe.timerange).to eql((1000..1700))
      expect(@subject.current_timeframe.level).to eql(1)
    end
  end

  describe '.opened?' do
    it "returns if it's opened" do
      expect(@subject.opened?).to eql(true)
    end
  end

  describe '.reopen' do
    it "returns next opened timeframe" do
      expect(@subject.reopen.date.to_s).to eql("2014-07-31")
      expect(@subject.reopen.timeframe.timerange.to_s).to eql("800..1000")
      expect(@subject.reopen.timeframe.level).to eql(1)
    end
  end

  describe '.next' do
    it "returns the three next timeframes" do
      next_timeframes = @subject.next
      expect(next_timeframes[0].date.to_s).to eql("2014-07-31")
      expect(next_timeframes[0].timeframe.timerange.to_s).to eql("800..1000")
      expect(next_timeframes[0].timeframe.level).to eql(1)

      expect(next_timeframes[1].date.to_s).to eql("2014-07-31")
      expect(next_timeframes[1].timeframe.timerange.to_s).to eql("1000..1700")
      expect(next_timeframes[1].timeframe.level).to eql(1)

      expect(next_timeframes[2].date.to_s).to eql("2014-08-01")
      expect(next_timeframes[2].timeframe.timerange.to_s).to eql("800..1000")
      expect(next_timeframes[2].timeframe.level).to eql(2)
    end
  end
end
