require 'test_helper'
require 'fixtures/base_fixture'

if ENV['BENCH']
  require 'minitest/benchmark'

  class TestPeriodConverterBench < Minitest::Benchmark
    def bench_parser
      Time.zone = "Europe/Paris"
      assert_performance_constant 0.9999 do |n|
        period = TurbaChronos::PeriodConverter.new('25/08:28/08')
        period.parse
      end
    end
  end
end

class TestPeriodConverter < Minitest::Test
  def setup
    Time.zone = "Europe/Paris"
  end

  def test_two_dates
    period = TurbaChronos::PeriodConverter.new('25/08:28/08')
    assert_equal period.parse.first.from.day, 25
    assert_equal period.parse.first.from.month, 8
    assert_equal period.parse.first.to.day, 28
    assert_equal period.parse.first.to.month, 8
  end

  def test_one_date
    period = TurbaChronos::PeriodConverter.new('25/08')
    assert_equal period.parse.first.from.day, 25
    assert_equal period.parse.first.from.month, 8
    assert_equal period.parse.first.to.day, 25
    assert_equal period.parse.first.to.month, 8
  end

  def test_one_month
    period = TurbaChronos::PeriodConverter.new('august')
    assert_equal period.parse.first.from.day, 1
    assert_equal period.parse.first.from.month, 8
    assert_equal period.parse.first.to.day, 31
    assert_equal period.parse.first.to.month, 8
  end

  def test_two_months
    period = TurbaChronos::PeriodConverter.new('august-october')
    assert_equal period.parse.first.from.day, 1
    assert_equal period.parse.first.from.month, 8
    assert_equal period.parse.first.to.day, 31
    assert_equal period.parse.first.to.month, 10
  end

  def test_stored_dates
    period = TurbaChronos::PeriodConverter.new('ponts_mai')
    assert_equal period.parse.first.from.day, 1
    assert_equal period.parse.first.from.month, 5
    assert_equal period.parse.first.to.day, 3
    assert_equal period.parse.first.to.month, 5
  end
end
