require 'test_helper'
require 'fixtures/base_fixture'

class TestTimeline < Minitest::Test
  def setup
    Time.zone = "Europe/Paris"
    new_time = Time.zone.local(2015, 6, 8, 12, 25, 0)
    Timecop.freeze(new_time)

    from = Time.zone.parse("June 08 2015, 00:00").iso8601
    to = Time.zone.parse("June 14 2015, 23:59").iso8601
    TurbaChronos.current_numeric_time = Time.now.utc.strftime("%k%M").to_i
    @timeline = TurbaChronos::Timeline.new(base_fixture.periods, Time.zone.parse(from), Time.zone.parse(to))
  end

  def test_current_timeframe
    assert_equal @timeline.current_timeframe.timerange, (1000..1700)
    assert_equal @timeline.current_timeframe.level, 1
  end

  def test_timeranges_for_days
    assert_equal @timeline.timeranges_for_days[:timeranges], [0..800, 800..1000, 1000..1700, 1700..2359]
    assert_equal @timeline.timeranges_for_days[:business_timeranges], [800..1000, 1000..1700]
  end


  def test_opened?
    assert_equal @timeline.opened?, true
  end


  def test_days
    assert_equal @timeline.days.count, 7
  end

  def test_next
    assert_equal @timeline.next.first.timeframe.level, 2
  end

  def test_levels
    assert_equal @timeline.levels, [1, 2, 6]
  end

  # def test_current_level
  #   assert_equal @table.current_level, 5
  # end

  def teardown
    Timecop.return
  end
end
